@@ -460,10 +460,18 @@ pub fn create_empty_branch(
     branch_name: impl AsRef<str>,
 ) -> Result<()> {
     let mut empty_contents: HashMap<PathBuf, String> = HashMap::new();
-    empty_contents.insert(
-        PathBuf::from("README.md"),
-        "# TRS responses generated by gh-trs".to_string(),
-    );
+
+    let readme_content = r#"
+# TRS responses generated by gh-trs
+
+## Docs
+
+- [GitHub - suecharo/gh-trs](https://github.com/suecharo/gh-trs)
+- [GA4GH - Tool Registry Service API](https://www.ga4gh.org/news/tool-registry-service-api-enabling-an-interoperable-library-of-genomics-analysis-tools/)
+- [GitHub - ga4gh/tool-registry-service-schemas](https://github.com/ga4gh/tool-registry-service-schemas)
+"#.to_string();
+
+    empty_contents.insert(PathBuf::from("README.md"), readme_content);
     let empty_tree_sha = create_tree(&gh_token, &owner, &name, None::<String>, empty_contents)?;
     let empty_commit_sha = create_commit(
         &gh_token,
